@@ -1,7 +1,15 @@
+// algebra.h - written and placed in the public domain by Wei Dai
+
+//! \file
+//! \headerfile algebra.h
+//! \brief Classes for performing mathematics over different fields
+
 #ifndef CRYPTOPP_ALGEBRA_H
 #define CRYPTOPP_ALGEBRA_H
 
 #include "config.h"
+#include "misc.h"
+#include "integer.h"
 
 NAMESPACE_BEGIN(CryptoPP)
 
@@ -47,9 +55,10 @@ public:
 	typedef T Element;
 
 	AbstractRing() {m_mg.m_pRing = this;}
-	AbstractRing(const AbstractRing &source): AbstractGroup<T>(source)
-	    {m_mg.m_pRing = this;}
-	AbstractRing& operator=(const AbstractRing &source) {return *this;}
+	AbstractRing(const AbstractRing &source)
+		{CRYPTOPP_UNUSED(source); m_mg.m_pRing = this;}
+	AbstractRing& operator=(const AbstractRing &source)
+		{CRYPTOPP_UNUSED(source); return *this;}
 
 	virtual bool IsUnit(const Element &a) const =0;
 	virtual const Element& MultiplicativeIdentity() const =0;
@@ -121,7 +130,7 @@ struct BaseAndExponent
 {
 public:
 	BaseAndExponent() {}
-	BaseAndExponent(const T &b, const E &e) : base(b), exponent(e) {}
+	BaseAndExponent(const T &base, const E &exponent) : base(base), exponent(exponent) {}
 	bool operator<(const BaseAndExponent<T, E> &rhs) const {return exponent < rhs.exponent;}
 	T base;
 	E exponent;
@@ -209,7 +218,7 @@ public:
 		{Element::Divide(r, q, a, d);}
 
 	bool operator==(const EuclideanDomainOf<T> &rhs) const
-		{return true;}
+		{CRYPTOPP_UNUSED(rhs); return true;}
 
 private:
 	mutable Element result;
